from flask import Flask, request, jsonify
import base64
import pdfplumber
import re
import io  # Required to convert bytes to file-like object

app = Flask(__name__)

def extract_due_date(pdf_bytes):
    """Extract the due date from a PDF file."""
    try:
        with pdfplumber.open(io.BytesIO(pdf_bytes)) as pdf:  # ✅ Wrap in BytesIO
            for page in pdf.pages:
                text = page.extract_text()
                if text:
                    match = re.search(r"Due Date: (\d{4}-\d{2}-\d{2})", text)
                    if match:
                        return match.group(1)
    except Exception as e:
        return str(e)  # Return error message if extraction fails
    return None

@app.route('/extract', methods=['POST'])
def extract():
    """API endpoint to process the PDF and extract due date."""
    try:
        data = request.json
        if not data or 'fileContent' not in data:
            return jsonify({"error": "Invalid request, missing fileContent"}), 400
        
        pdf_content = base64.b64decode(data['fileContent'])
        due_date = extract_due_date(pdf_content)
        
        response_data = {
            "dueDate": due_date or "Not Found",
            "eventName": "Form Due Date",
            "sender": "Unknown Sender"  # Modify to get actual sender if needed
        }
        
        return jsonify(response_data)
    except Exception as e:
        return jsonify({"error": str(e)}), 500

if __name__ == '__main__':
    app.run()