const express = require("express");
const cors = require("cors");
const path = require("path");
const axios = require("axios");
const bodyParser = require("body-parser");
const app = express();
const port = 3000;

app.use(cors());
app.use(bodyParser.json({ limit: "10mb" })); // Handle large PDF attachments
app.use(express.static("dist")); // Serve bundled files from Webpack output

app.get("/", (req, res) => {
  res.send("Outlook Add-in is running");
});

// Route to send PDF to the Flask API
app.post("/process-pdf", async (req, res) => {
  try {
    const { fileContent } = req.body;
    
    // Ensure we have a file
    if (!fileContent) {
      return res.status(400).json({ error: "No file content provided" });
    }

    // Send the PDF to Flask API
    const response = await axios.post("http://dueauto.com/outlook-addin/flask_app/extract", {

      fileContent: fileContent,
    });

    // Return extracted data
    res.json({
      dueDate: response.data.dueDate || "Not Found",
      eventName: response.data.eventName || "Unknown Event",
      sender: response.data.sender || "Unknown Sender"
    });
  } catch (error) {
    console.error("Error processing PDF:", error);
    res.status(500).json({ error: "Failed to process PDF" });
  }
});

app.listen(port, () => {
  console.log(`Server running on https://dueauto.com:${port}`);
});